@@ -1,23 +1,22 @@
 // Copyright (c) Facebook, Inc. and its affiliates
 // SPDX-License-Identifier: MIT OR Apache-2.0
 
-use include_dir::include_dir as include_directory;
-use std::{
-    collections::{BTreeMap, HashMap},
-    io::{Result, Write},
-    path::PathBuf,
-};
-
-use serde_reflection::{ContainerFormat, Format, FormatHolder, Named, Registry, VariantFormat};
-
 use crate::{
     common,
     indent::{IndentConfig, IndentedWriter},
     CodeGeneratorConfig,
 };
 use heck::CamelCase;
+use include_dir::include_dir as include_directory;
+use serde_reflection::{ContainerFormat, Format, FormatHolder, Named, Registry, VariantFormat};
+use std::{
+    collections::{BTreeMap, HashMap},
+    io::{Result, Write},
+    path::PathBuf,
+};
 
-/// Main configuration object for code-generation in TypeScript.
+/// Main configuration object for code-generation in TypeScript, powered by
+/// the Deno runtime.
 pub struct CodeGenerator<'a> {
     /// Language-independent configuration.
     config: &'a CodeGeneratorConfig,
@@ -91,15 +90,15 @@ where
         writeln!(
             self.out,
             r#"
-import {{ Serializer }} from '../serde/serializer';
-import {{ Deserializer }} from '../serde/deserializer';
-import {{ Optional, Seq, Tuple, ListTuple, unit, bool, int8, int16, int32, int64, int128, uint8, uint16, uint32, uint64, uint128, float32, float64, char, str, bytes}} from '../serde/types';
-"#
+import {{ Serializer, Deserializer }} from '../serde/mod.ts';
+import {{ BcsSerializer, BcsDeserializer }} from '../bcs/mod.ts';
+import {{ Optional, Seq, Tuple, ListTuple, unit, bool, int8, int16, int32, int64, int128, uint8, uint16, uint32, uint64, uint128, float32, float64, char, str, bytes }} from '../serde/mod.ts';
+"#,
         )?;
         for namespace in self.generator.namespaces_to_import.iter() {
             writeln!(
                 self.out,
-                "import * as {} from '../{}';\n",
+                "import * as {} from '../{}.ts';\n",
                 namespace.to_camel_case(),
                 namespace
             )?;
@@ -721,10 +720,6 @@ impl crate::SourceInstaller for Installer {
         let generator = CodeGenerator::new(config);
         generator.output(&mut file, registry)?;
         Ok(())
-
-        // let generator = CodeGenerator::new(config, true);
-        // generator.write_source_files(self.install_dir.clone(), registry)?;
-        // Ok(())
     }
 
     fn install_serde_runtime(&self) -> std::result::Result<(), Self::Error> {
